@@ -140,6 +140,13 @@ class TestFile:
         f.folder = "words\\docx\\"
         return f
 
+    @classmethod
+    def video(cls):
+        f = TestFile()
+        f.file_name = "sample.avi"
+        f.folder = "video\\avi\\"
+        return f
+
     @classmethod
     def not_exist(cls):
         f = TestFile()
